#include <libpv_config.h>

#include <libpv.h>
#include <pv_lock.h>
#include <pv_bs.h>

/**
 * pv_flush - flush process variables onto backing store
 * @engine_anon:  Engine to work with
 * @ptr: flush this memory area into the backing store
 * @len: memory area's lenght in bytes
 *
 * Description: Flushes part of the process image onto
 * the backing store. If the image is wholy mapped this
 * function do nothing. In this case there is no need to
 * flush anything.
 **/
void pv_flush(pv_engine_t	*engine_anon,
	      void		*ptr,
	      size_t		len)
{
	struct pv_engine	*engine = (struct pv_engine *)engine_anon;
	struct pv_backing_store	*store = &engine->store;
	off_t			offset = ptr - store->map;

	if (store->shmid < 0)
		return;

	if (offset >= store->size)
		return;	/* FIXME: Should be a error message! */

	len = MIN(len, store->size - offset);

	pv_bs_flush_rel(engine, offset, len);
}

/**
 * pv_lock - lock the engine to some work init
 * @engine_anon: Engine to work with
 *
 * Description:
 **/
void pv_lock(pv_engine_t	*engine_anon)
{
	struct pv_engine *engine = (struct pv_engine *)engine_anon;

	pv_lock_lock(engine);
}

/**
 * pv_unlock - unlocks a previous locked engine
 * @engine_anon: Engine to work with
 *
 * Description:
 **/
void pv_unlock(pv_engine_t	*engine_anon)
{
	struct pv_engine *engine = (struct pv_engine *)engine_anon;

	pv_lock_unlock(engine);
}
